#[non_exhaustive]pub enum Fidelity {
Exact,
Approximate {
requested: Scalar,
achieved: Scalar,
},
}Expand description
Whether the parts reproduce the input or merely approximate it.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Exact
Every part is convex to within tolerance; the union is the input.
Approximate
Parts are convex to within a bound larger than tolerance.
Fields