pub fn convex_decompose(
mesh: &TriMesh,
strategy: Strategy,
tolerance: Tolerance,
) -> Result<Decomposition, DecomposeError>Expand description
Decompose a closed two-manifold solid into convex parts.
Errors
Refuses a ragged index buffer, an out-of-range index, an input that is not a closed two-manifold solid, a non-positive concavity bound, and a decomposition that exceeds the part budget.